pub struct DiagramRegistry {
providers: HashMap<String, Arc<dyn DiagramProvider + Send + Sync>>,
}Fields
providers: HashMap<String, Arc<dyn DiagramProvider + Send + Sync>>Implementations
Sourceimpl DiagramRegistry
impl DiagramRegistry
pub fn new( capabilities: &Capabilities, config: &Config, browser_manager: Option<Arc<BrowserManager>>, ) -> Self
Sourcepub fn get(&self, name: &str) -> Option<Arc<dyn DiagramProvider + Send + Sync>>
pub fn get(&self, name: &str) -> Option<Arc<dyn DiagramProvider + Send + Sync>>
Returns the provider for a given diagram type, if available.
Sourcepub fn known_types(&self) -> Vec<String>
pub fn known_types(&self) -> Vec<String>
Returns the list of all registered diagram type names.