pub struct ProblemDetails {
pub problem_type: String,
pub title: String,
pub status: u16,
pub detail: Option<String>,
pub instance: Option<String>,
}Expand description
RFC 7807: Problem Details for HTTP APIs Provides a standard way to represent errors in a machine-readable format.
Fields
problem_type: StringA URI reference [RFC3986] that identifies the problem type.
title: StringA short, human-readable summary of the problem type.
status: u16The HTTP status code generated by the origin server for this occurrence of the problem.
detail: Option<String>A human-readable explanation specific to this occurrence of the problem.
instance: Option<String>A URI reference that identifies the specific occurrence of the problem.
Implementations