init_metrics

Function init_metrics 

pub fn init_metrics() -> PrometheusHandle
Initialize the Prometheus metrics exporter.

This registers the recorder and defines all core metrics (counters, histograms, gauges) according to ADR 0006.

Returns a handle that can be used to scrape metrics if the endpoint is enabled. This function is idempotent and safe to call multiple times (e.g. in integration tests).