Struct PrometheusHandle
pub struct PrometheusHandle {
inner: Arc<Inner>,
}Expand description
Handle for accessing metrics stored via [PrometheusRecorder].
In certain scenarios, it may be necessary to directly handle requests that would otherwise be
handled directly by the HTTP listener, or push gateway background task. PrometheusHandle
allows rendering a snapshot of the current metrics stored by an installed [PrometheusRecorder]
as a payload conforming to the Prometheus exposition format.
Fields
inner: Arc<Inner>Implementations
impl PrometheusHandle
impl PrometheusHandle
pub fn render(&self) -> String
pub fn render(&self) -> String
Takes a snapshot of the metrics held by the recorder and generates a payload conforming to the Prometheus exposition format.
pub fn run_upkeep(&self)
pub fn run_upkeep(&self)
Performs upkeeping operations to ensure metrics held by recorder are up-to-date and do not grow unboundedly.