pub fn find_api_key_entry<'a>(
auth_config: &'a AuthConfig,
key: &str,
) -> Option<&'a ApiKeyEntry>Expand description
Looks up the ApiKeyEntry for a given key string.
Returns None if the key is not found or auth is disabled.
pub fn find_api_key_entry<'a>(
auth_config: &'a AuthConfig,
key: &str,
) -> Option<&'a ApiKeyEntry>Looks up the ApiKeyEntry for a given key string.
Returns None if the key is not found or auth is disabled.